@@ -52,16 +52,18 @@ def get_authorization(client):
     if 'ssh_key' in system.config[client]:
         _ssh_key = system.config[mode.Client.ORIGIN]['ssh_key']
 
+    _ssh_port = system.config[client]['port'] if 'port' in system.config[client] else 22
+
     if _ssh_key is None:
         if system.config['use_sshpass']:
             # In combination with SSHPASS environment variable
             # https://www.redhat.com/sysadmin/ssh-automation-sshpass
-            return f'--rsh="sshpass -e ssh -o StrictHostKeyChecking=no -l {system.config[client]["user"]}"'
+            return f'--rsh="sshpass -e ssh -p{_ssh_port} -o StrictHostKeyChecking=no -l {system.config[client]["user"]}"'
         else:
-            return ''
+            return f'-e "ssh -p{_ssh_port}"'
     else:
         # Provide ssh key file path for ssh authentication
-        return f'-e "ssh -i {_ssh_key}"'
+        return f'-e "ssh -i {_ssh_key} -p{_ssh_port}"'
 
 
 def get_host(client):
